"""Initialize the app"""

# AA TaxSystem
from taxsystem.app_settings import TAXSYSTEM_APP_NAME

__version__ = "0.5.8"
__title__ = "Tax System"

USER_AGENT_TEXT = f"{TAXSYSTEM_APP_NAME} v{__version__}"
